@@ -1,5 +1,6 @@
 #[cfg(feature = "serialization")]
 use serde::{Deserialize, Serialize};
+use std::ffi::{OsStr, OsString};
 use std::num::NonZeroU32;
 use std::{error, fmt};
 
@@ -95,10 +96,7 @@ impl FileId {
 /// [`Rc<str>`]: std::rc::Rc
 /// [`Arc<str>`]: std::sync::Arc
 #[derive(Clone, Debug)]
-pub struct Files<Source>
-where
-    Source: AsRef<str>,
-{
+pub struct Files<Source> {
     files: Vec<File<Source>>,
 }
 
@@ -122,7 +120,7 @@ where
 
     /// Add a file to the database, returning the handle that can be used to
     /// refer to it again.
-    pub fn add(&mut self, name: impl Into<String>, source: Source) -> FileId {
+    pub fn add(&mut self, name: impl Into<OsString>, source: Source) -> FileId {
         let file_id = FileId::new(self.files.len());
         self.files.push(File::new(name.into(), source.into()));
         file_id
@@ -160,7 +158,7 @@ where
     ///
     /// assert_eq!(files.name(file_id), name);
     /// ```
-    pub fn name(&self, file_id: FileId) -> &str {
+    pub fn name(&self, file_id: FileId) -> &OsStr {
         self.get(file_id).name()
     }
 
@@ -281,12 +279,9 @@ where
 /// A file that is stored in the database.
 #[derive(Debug, Clone)]
 #[cfg_attr(feature = "serialization", derive(Deserialize, Serialize))]
-struct File<Source>
-where
-    Source: AsRef<str>,
-{
+struct File<Source> {
     /// The name of the file.
-    name: String,
+    name: OsString,
     /// The source code of the file.
     source: Source,
     /// The starting byte indices in the source code.
@@ -305,7 +300,7 @@ impl<Source> File<Source>
 where
     Source: AsRef<str>,
 {
-    fn new(name: String, source: Source) -> Self {
+    fn new(name: OsString, source: Source) -> Self {
         let line_starts = compute_line_starts(source.as_ref());
 
         File {
@@ -321,7 +316,7 @@ where
         self.line_starts = line_starts;
     }
 
-    fn name(&self) -> &str {
+    fn name(&self) -> &OsStr {
         &self.name
     }
 
